==> 0.8.1.tar.gz: zigbrains/modules/project/src/main/java/com/falsepattern/zigbrains/project/openapi/components/ZigProjectSettings.java <==
/*
 * Copyright 2023 FalsePattern
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.falsepattern.zigbrains.project.openapi.components;

import com.falsepattern.zigbrains.project.toolchain.AbstractZigToolchain;
import com.falsepattern.zigbrains.project.toolchain.ZigToolchainProvider;
import com.intellij.util.io.PathKt;
import com.intellij.util.xmlb.annotations.Transient;
import org.jetbrains.annotations.Nullable;

import java.nio.file.Path;

public class ZigProjectSettings {
    public String toolchainHomeDirectory = null;
    public String explicitPathToStd = null;

    public String getExplicitPathToStd() {
        return explicitPathToStd;
    }

    public void setExplicitPathToStd(String value) {
        explicitPathToStd = value;
    }

    @Transient
    public @Nullable AbstractZigToolchain getToolchain() {
        if (toolchainHomeDirectory == null) {
            return null;
        }
        return ZigToolchainProvider.findToolchain(Path.of(toolchainHomeDirectory));
    }

    @Transient
    public void setToolchain(@Nullable AbstractZigToolchain value) {
        if (value == null) {
            toolchainHomeDirectory = null;
            return;
        }
        var loc = value.location;
        if (loc == null) {
            toolchainHomeDirectory = null;
            return;
        }
        toolchainHomeDirectory = PathKt.getSystemIndependentPath(loc);
    }
}

==> 16.1.3.tar.gz: zigbrains/modules/project/src/main/java/com/falsepattern/zigbrains/project/openapi/components/ZigProjectSettings.java <==
/*
 * Copyright 2023-2024 FalsePattern
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.falsepattern.zigbrains.project.openapi.components;

import com.falsepattern.zigbrains.project.toolchain.AbstractZigToolchain;
import com.falsepattern.zigbrains.project.toolchain.ZigToolchainProvider;
import com.intellij.util.io.PathKt;
import com.intellij.util.xmlb.annotations.Transient;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.jetbrains.annotations.Nullable;

import java.nio.file.Path;

@Data
@AllArgsConstructor
@NoArgsConstructor
public class ZigProjectSettings {
    public boolean overrideStdPath;
    public String explicitPathToStd;
    public String toolchainHomeDirectory;

    public ZigProjectSettings(String explicitPathToStd, AbstractZigToolchain toolchain) {
        this(explicitPathToStd != null, explicitPathToStd, null);
        setToolchain(toolchain);
    }

    @Transient
    public @Nullable AbstractZigToolchain getToolchain() {
        if (toolchainHomeDirectory == null) {
            return null;
        }
        return ZigToolchainProvider.findToolchain(Path.of(toolchainHomeDirectory));
    }

    @Transient
    public void setToolchain(@Nullable AbstractZigToolchain value) {
        if (value == null) {
            toolchainHomeDirectory = null;
            return;
        }
        var loc = value.getLocation();
        if (loc == null) {
            toolchainHomeDirectory = null;
            return;
        }
        toolchainHomeDirectory = PathKt.getSystemIndependentPath(loc);
    }
}
